@@ -48,6 +48,10 @@
     #define XSIMD_DEFAULT_ALIGNMENT 32
 #elif XSIMD_X86_INSTR_SET >= XSIMD_X86_SSE2_VERSION
     #define XSIMD_DEFAULT_ALIGNMENT 16
+#elif XSIMD_ARM_INSTR_SET >= XSIMD_ARM8_64_NEON_VERSION
+    #define XSIMD_DEFAULT_ALIGNMENT 32
+#elif XSIMD_ARM_INSTR_SET >= XSIMD_ARM7_NEON_VERSION
+    #define XSIMD_DEFAULT_ALIGNMENT 16
 #endif
 
 #endif
